#
# spec file for package liburcu0
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define fullname userspace-rcu

Name:           liburcu0
Version:        0.8.8
Release:        5.3
Source:         http://www.lttng.org/files/urcu/%{fullname}-%{version}.tar.bz2
Patch1:         %{fullname}-extradocs.patch
Patch2:         userspace-rcu-aarch64.patch
Patch3:         userspace-rcu-ppc64-use-ppc.patch
Patch4:         userspace-rcu-ppc64le.patch
Summary:        Userspace RCU Implementation
License:        LGPL-2.1+ and GPL-2.0 and GPL-3.0+ and MIT
Group:          Development/Languages/C and C++
Url:            http://liburcu.org
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Userspace RCU Implementation from LTTng UST.

%package -n liburcu-devel

Summary:        Userspace RCU Implementation
Group:          Development/Languages/C and C++
Requires:       liburcu0 = %{version}

%description -n liburcu-devel
Userspace RCU Implementation from LTTng UST.

%package -n urcu-docs

Summary:        Userspace RCU Documentation
Group:          Development/Languages/C and C++
Requires:       liburcu0 = %{version}

%description -n urcu-docs
This package contains API documention for liburcu

%prep
%setup -q -n %{fullname}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
autoreconf -fi
%configure --docdir=%{_docdir}/%{fullname}
make

%install
make DESTDIR=%buildroot install
rm -vf %buildroot%{_libdir}/*.la

%clean
rm -rf %buildroot

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/*.so.*

%files -n liburcu-devel
%defattr(-,root,root)
%{_prefix}/include/*
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/liburcu*.pc

%files -n urcu-docs
%defattr(-,root,root)
%dir %{_docdir}/%{fullname}
%{_docdir}/%{fullname}/*

%changelog
* Tue Jul  5 2016 hare@suse.de
- add userspace-rcu-ppc64-use-ppc.patch
  Use 'ppc' for 'ppc64'
- add userspace-rcu-ppc64le.patch (bsc#987526)
- Enable build on all architectures
* Mon Oct  5 2015 tonyj@suse.com
- Update to version 0.8.8, required for upgrade of other lttng
  packages from 2.7.0-rc1 to 2.7.0 (FATE#319273)
  Changelog 0.8.8:
  * Disable sys_membarrier
  * Fix: volatile in assert()
  * uatomic: Specify complete types for atomic function calls
  * Fix: handle sys_futex() FUTEX_WAIT interrupted by signal
  * Fix: compat_futex.c: *uaddr should be read as volatile
  * Fix: make benchmark test run in oot build
  * Fix: call_rcu_thread() affinity failure
  * urcu: fix deprecation warning with new glibc
* Mon Aug 31 2015 dmueller@suse.com
- add userspace-rcu-aarch64.patch (fate#318370)
  enables build for aarch64
* Wed Jul 29 2015 tonyj@suse.com
- Update to version 0.8,7 (FATE#319273)
  Changelog 0.8.7:
  * Fix: deadlock when thread join is issued in read-side C.S.
  * Fix: rename RCU_DEBUG to DEBUG_RCU in urcu-qsbr.h
  * Mark braced-groups within expressions with __extension__
  * Fix: compat_futex_noasync race condition
  * Fix: documentation: urcu-pointer.h: s/rcu_dereference_pointer/rcu_dereference/
  * Fix: call rcu should call internal RCU API
  Changelog 0.8.6:
  * Fix: silence gcc -Wextra warning
  * compiler: use __GNUC__ instead of the undefined __GNUC_MAJOR__
  * Fix: lfstack reversed empty/non-empty return value
  * lfstack: fix: add missing __cds_lfs_init
  Changelog 0.8.5:
  * Fix: preserve example files' timestamps when copying
  * rculfhash: remove duplicated code
  * rculfhash: handle pthread_create failures
  * rculfhash: fall back to single-threaded resize on calloc failure
  * x86: drop extra semi-colon in caa_cpu_relax
  * Fix: Use after free in rcu_barrier()
  * Fix: rcu_barrier(): uninitialized futex field
  * call_rcu threads should clear their PAUSED flag when they unpause
  * Fix: bring back dummy rcu_bp_exit symbol
* Tue Apr 15 2014 tonyj@suse.com
- Update to version 0.8.4
  Changelog 0.8.4:
  * Fix: move wait loop increment before first conditional block
  Changelog 0.8.3:
  * Fix: high cpu usage in synchronize_rcu with long RCU read-side C.S.
  Changelog 0.8.2:
  * Fix: out of tree build: doc/examples
  * Fix: out of tree build tests/common
  * tests/unit: use lib rather than source
  * automake: Rename INCLUDES to AM_CPPFLAGS (new name)
  * tests regressions: use lib rather than recompile from source
  * tests: use common lib rather than recompile compat sources
  * urcu tests: use lib rather than compile from source
  * urcu mb tests: use lib rather than recompile from source
  * urcu signal tests: use library rather than recompile source
  * tests: move yield debug to common test library
  * tests urcu bp: use lib rather than recompile source
  * test_urcu_defer: link on urcu lib rather than recompile source
  * tests/benchmark: use urcu qsbr lib rather than recompile from source
  * Pass the CC variable to the example Makefiles
  * Fix: urcu-bp interaction with threads vs constructors/destructors
  * Fix undefined NULL pointer arithmetic
  * Blacklist ARM gcc 4.8.0, 4.8.1, 4.8.2
  * rculfhash: document max_nr_buckets = 0
* Mon Feb 10 2014 tonyj@suse.com
- Update to version 0.8.1: see ChangeLog in package 'urcu-docs' for details
- Add license files to docs package.
* Mon Mar 11 2013 tonyj@suse.com
- Update to version 0.7.6 (FATE#314846)
  Changelog 0.7.6:
  * Discourage use of pthread_atfork() for call_rcu handlers
  * Fix call_rcu fork handling
  * test: fork handling
  * Fix TLS detection: test with linker, add --disable-compiler-tls
  * Cleanup: cast pthread_self() return value to unsigned long
  * Fallback mechanism not working on platform where TLS is unsupported
  Changelog 0.7.5:
  * 19cf3ae Fix: call_rcu list corruption on teardown
  * Ensure that read-side functions meet 10-line LGPL criterion
  * tls-compat.h: document sigaltstack(2) limitation
  * urcu: add notice to URCU_TLS() for it is not strictly async-signal-safe
  * Document sigaltstack(2) limitation
  * Documentation: update LICENSE file
  Changelog 0.7.4:
  * rculfhash API documentation: document destroy RCU read-lock constraint
  * Fix: rculfhash should be offline while waiting for resize to complete
  * Add missing entry to gitignore
  * urcu: move busy-wait code and name it ___cds_wfq_node_sync_next()
  * urcu: fix compat_futex_noasync()
  * urcu: add hint to DEFINE_URCU_TLS() for compound types
  * Fix: CAA_BUILD_BUG_ON should refer to CAA_BUILD_BUG_ON_ZERO
  * Add MIPS support
  * Compatibility: remove bash-ismsm from test scripts
  * Fix inappropriate lib behavior: don't call exit()
  * Fix: re-enable compatibility with autoconf < 2.64
  * Fix c99 compatibility: use __asm__ and __volatile__ in public headers
  * Fix c99 compatibility: use __typeof__ instead of typeof in public headers
  * warning fix: tests urcutorture for NetBSD 5
* Mon Jun  4 2012 tonyj@suse.com
- Update to version 0.7.3
* Wed May 23 2012 tonyj@suse.com
- Update to version 0.7
- Package docs
* Wed Jan  4 2012 tonyj@suse.com
- Update to version 0.6.7
* Sat Oct 22 2011 jblunck@opensuse.org
- Update to version 0.6.5.
* Tue May  3 2011 jblunck@opensuse.org
- Update to version 0.5.4.
* Fri Oct 22 2010 tonyj@novell.com
- Add buildservice cleanup patch.
* Sat Aug 21 2010 tonyj@novell.com
- Update to version 0.4.6
* Sat Oct 17 2009 jblunck@suse.de
- Update to version 0.2.3-alpha.
* Mon May 11 2009 jblunck@suse.de
- packaged liburcu version 0.0
